@@ -2,8 +2,9 @@
 Utility methods
 '''
 
-class _Helpers():
-    
+
+class Helpers:
+    @staticmethod
     def save_state_dict_tensorflow(model):
         state_dict = {}
         for index, layer in enumerate(model.layers):
@@ -11,14 +12,13 @@ class _Helpers():
             raw_weights = model.layers[index].weights
             layer_weights = []
             for weight_tensors in raw_weights:
-                layer_weights.append(weight_tensors.numpy())      
-            state_dict[layer.name] = [layer_class, layer_weights] 
+                layer_weights.append(weight_tensors.numpy())
+            state_dict[layer.name] = [layer_class, layer_weights]
         return state_dict
 
-
+    @staticmethod
     def load_state_dict_tensorflow(model, state_dict):
         for index, layer in enumerate(model.layers):
             raw_weights = model.layers[index].weights
             for index, weight_tensors in enumerate(raw_weights):
                 weight_tensors.assign(state_dict[layer.name][1][index])
-
